.has-background {
  background-color: var(--bulma-background);
}

.has-text-white {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-l)) !important;
}

.has-background-white {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-l)) !important;
}

.has-text-white-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-invert-l)) !important;
}

.has-background-white-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-invert-l)) !important;
}

.has-text-white-on-scheme {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-on-scheme-l)) !important;
}

.has-background-white-on-scheme {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-on-scheme-l)) !important;
}

.has-text-white-light {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-light-l)) !important;
}

.has-background-white-light {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-light-l)) !important;
}

.has-text-white-light-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-light-invert-l)) !important;
}

.has-background-white-light-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-light-invert-l)) !important;
}

.has-text-white-dark {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-dark-l)) !important;
}

.has-background-white-dark {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-dark-l)) !important;
}

.has-text-white-dark-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-dark-invert-l)) !important;
}

.has-background-white-dark-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-dark-invert-l)) !important;
}

.has-text-white-soft {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-soft-l)) !important;
}

.has-background-white-soft {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-soft-l)) !important;
}

.has-text-white-bold {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-bold-l)) !important;
}

.has-background-white-bold {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-bold-l)) !important;
}

.has-text-white-soft-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-white-soft-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-white-bold-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-white-bold-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-white-00 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-00-l)) !important;
}

.has-background-white-00 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-00-l)) !important;
}

.has-text-white-00-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-00-invert-l)) !important;
}

.has-background-white-00-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-00-invert-l)) !important;
}

.has-text-white-05 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-05-l)) !important;
}

.has-background-white-05 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-05-l)) !important;
}

.has-text-white-05-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-05-invert-l)) !important;
}

.has-background-white-05-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-05-invert-l)) !important;
}

.has-text-white-10 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-10-l)) !important;
}

.has-background-white-10 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-10-l)) !important;
}

.has-text-white-10-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-10-invert-l)) !important;
}

.has-background-white-10-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-10-invert-l)) !important;
}

.has-text-white-15 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-15-l)) !important;
}

.has-background-white-15 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-15-l)) !important;
}

.has-text-white-15-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-15-invert-l)) !important;
}

.has-background-white-15-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-15-invert-l)) !important;
}

.has-text-white-20 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-20-l)) !important;
}

.has-background-white-20 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-20-l)) !important;
}

.has-text-white-20-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-20-invert-l)) !important;
}

.has-background-white-20-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-20-invert-l)) !important;
}

.has-text-white-25 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-25-l)) !important;
}

.has-background-white-25 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-25-l)) !important;
}

.has-text-white-25-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-25-invert-l)) !important;
}

.has-background-white-25-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-25-invert-l)) !important;
}

.has-text-white-30 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-30-l)) !important;
}

.has-background-white-30 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-30-l)) !important;
}

.has-text-white-30-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-30-invert-l)) !important;
}

.has-background-white-30-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-30-invert-l)) !important;
}

.has-text-white-35 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-35-l)) !important;
}

.has-background-white-35 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-35-l)) !important;
}

.has-text-white-35-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-35-invert-l)) !important;
}

.has-background-white-35-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-35-invert-l)) !important;
}

.has-text-white-40 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-40-l)) !important;
}

.has-background-white-40 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-40-l)) !important;
}

.has-text-white-40-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-40-invert-l)) !important;
}

.has-background-white-40-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-40-invert-l)) !important;
}

.has-text-white-45 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-45-l)) !important;
}

.has-background-white-45 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-45-l)) !important;
}

.has-text-white-45-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-45-invert-l)) !important;
}

.has-background-white-45-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-45-invert-l)) !important;
}

.has-text-white-50 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-50-l)) !important;
}

.has-background-white-50 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-50-l)) !important;
}

.has-text-white-50-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-50-invert-l)) !important;
}

.has-background-white-50-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-50-invert-l)) !important;
}

.has-text-white-55 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-55-l)) !important;
}

.has-background-white-55 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-55-l)) !important;
}

.has-text-white-55-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-55-invert-l)) !important;
}

.has-background-white-55-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-55-invert-l)) !important;
}

.has-text-white-60 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-60-l)) !important;
}

.has-background-white-60 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-60-l)) !important;
}

.has-text-white-60-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-60-invert-l)) !important;
}

.has-background-white-60-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-60-invert-l)) !important;
}

.has-text-white-65 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-65-l)) !important;
}

.has-background-white-65 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-65-l)) !important;
}

.has-text-white-65-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-65-invert-l)) !important;
}

.has-background-white-65-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-65-invert-l)) !important;
}

.has-text-white-70 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-70-l)) !important;
}

.has-background-white-70 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-70-l)) !important;
}

.has-text-white-70-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-70-invert-l)) !important;
}

.has-background-white-70-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-70-invert-l)) !important;
}

.has-text-white-75 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-75-l)) !important;
}

.has-background-white-75 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-75-l)) !important;
}

.has-text-white-75-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-75-invert-l)) !important;
}

.has-background-white-75-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-75-invert-l)) !important;
}

.has-text-white-80 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-80-l)) !important;
}

.has-background-white-80 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-80-l)) !important;
}

.has-text-white-80-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-80-invert-l)) !important;
}

.has-background-white-80-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-80-invert-l)) !important;
}

.has-text-white-85 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-85-l)) !important;
}

.has-background-white-85 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-85-l)) !important;
}

.has-text-white-85-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-85-invert-l)) !important;
}

.has-background-white-85-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-85-invert-l)) !important;
}

.has-text-white-90 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-90-l)) !important;
}

.has-background-white-90 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-90-l)) !important;
}

.has-text-white-90-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-90-invert-l)) !important;
}

.has-background-white-90-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-90-invert-l)) !important;
}

.has-text-white-95 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-95-l)) !important;
}

.has-background-white-95 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-95-l)) !important;
}

.has-text-white-95-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-95-invert-l)) !important;
}

.has-background-white-95-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-95-invert-l)) !important;
}

.has-text-white-100 {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-100-l)) !important;
}

.has-background-white-100 {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-100-l)) !important;
}

.has-text-white-100-invert {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-100-invert-l)) !important;
}

.has-background-white-100-invert {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), var(--bulma-white-100-invert-l)) !important;
}

a.has-text-white:hover, a.has-text-white:focus-visible,
button.has-text-white:hover,
button.has-text-white:focus-visible,
has-text-white.is-hoverable:hover,
has-text-white.is-hoverable:focus-visible {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), calc(var(--bulma-white-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-white:active,
button.has-text-white:active,
has-text-white.is-hoverable:active {
  color: hsl(var(--bulma-white-h), var(--bulma-white-s), calc(var(--bulma-white-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-white:hover, a.has-background-white:focus-visible,
button.has-background-white:hover,
button.has-background-white:focus-visible,
has-background-white.is-hoverable:hover,
has-background-white.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), calc(var(--bulma-white-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-white:active,
button.has-background-white:active,
has-background-white.is-hoverable:active {
  background-color: hsl(var(--bulma-white-h), var(--bulma-white-s), calc(var(--bulma-white-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-white {
  --h: var(--bulma-white-h);
  --s: var(--bulma-white-s);
  --l: var(--bulma-white-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-white-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-white-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-white-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-white-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-white-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-white-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-white-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-white-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-white-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-white-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-white-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-white-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-white-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-white-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-white-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-white-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-white-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-white-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-white-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-white-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-white-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-black {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-l)) !important;
}

.has-background-black {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-l)) !important;
}

.has-text-black-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-invert-l)) !important;
}

.has-background-black-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-invert-l)) !important;
}

.has-text-black-on-scheme {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-on-scheme-l)) !important;
}

.has-background-black-on-scheme {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-on-scheme-l)) !important;
}

.has-text-black-light {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-light-l)) !important;
}

.has-background-black-light {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-light-l)) !important;
}

.has-text-black-light-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-light-invert-l)) !important;
}

.has-background-black-light-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-light-invert-l)) !important;
}

.has-text-black-dark {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-dark-l)) !important;
}

.has-background-black-dark {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-dark-l)) !important;
}

.has-text-black-dark-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-dark-invert-l)) !important;
}

.has-background-black-dark-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-dark-invert-l)) !important;
}

.has-text-black-soft {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-soft-l)) !important;
}

.has-background-black-soft {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-soft-l)) !important;
}

.has-text-black-bold {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-bold-l)) !important;
}

.has-background-black-bold {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-bold-l)) !important;
}

.has-text-black-soft-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-black-soft-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-black-bold-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-black-bold-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-black-00 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-00-l)) !important;
}

.has-background-black-00 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-00-l)) !important;
}

.has-text-black-00-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-00-invert-l)) !important;
}

.has-background-black-00-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-00-invert-l)) !important;
}

.has-text-black-05 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-05-l)) !important;
}

.has-background-black-05 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-05-l)) !important;
}

.has-text-black-05-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-05-invert-l)) !important;
}

.has-background-black-05-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-05-invert-l)) !important;
}

.has-text-black-10 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-10-l)) !important;
}

.has-background-black-10 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-10-l)) !important;
}

.has-text-black-10-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-10-invert-l)) !important;
}

.has-background-black-10-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-10-invert-l)) !important;
}

.has-text-black-15 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-15-l)) !important;
}

.has-background-black-15 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-15-l)) !important;
}

.has-text-black-15-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-15-invert-l)) !important;
}

.has-background-black-15-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-15-invert-l)) !important;
}

.has-text-black-20 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-20-l)) !important;
}

.has-background-black-20 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-20-l)) !important;
}

.has-text-black-20-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-20-invert-l)) !important;
}

.has-background-black-20-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-20-invert-l)) !important;
}

.has-text-black-25 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-25-l)) !important;
}

.has-background-black-25 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-25-l)) !important;
}

.has-text-black-25-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-25-invert-l)) !important;
}

.has-background-black-25-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-25-invert-l)) !important;
}

.has-text-black-30 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-30-l)) !important;
}

.has-background-black-30 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-30-l)) !important;
}

.has-text-black-30-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-30-invert-l)) !important;
}

.has-background-black-30-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-30-invert-l)) !important;
}

.has-text-black-35 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-35-l)) !important;
}

.has-background-black-35 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-35-l)) !important;
}

.has-text-black-35-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-35-invert-l)) !important;
}

.has-background-black-35-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-35-invert-l)) !important;
}

.has-text-black-40 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-40-l)) !important;
}

.has-background-black-40 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-40-l)) !important;
}

.has-text-black-40-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-40-invert-l)) !important;
}

.has-background-black-40-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-40-invert-l)) !important;
}

.has-text-black-45 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-45-l)) !important;
}

.has-background-black-45 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-45-l)) !important;
}

.has-text-black-45-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-45-invert-l)) !important;
}

.has-background-black-45-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-45-invert-l)) !important;
}

.has-text-black-50 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-50-l)) !important;
}

.has-background-black-50 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-50-l)) !important;
}

.has-text-black-50-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-50-invert-l)) !important;
}

.has-background-black-50-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-50-invert-l)) !important;
}

.has-text-black-55 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-55-l)) !important;
}

.has-background-black-55 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-55-l)) !important;
}

.has-text-black-55-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-55-invert-l)) !important;
}

.has-background-black-55-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-55-invert-l)) !important;
}

.has-text-black-60 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-60-l)) !important;
}

.has-background-black-60 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-60-l)) !important;
}

.has-text-black-60-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-60-invert-l)) !important;
}

.has-background-black-60-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-60-invert-l)) !important;
}

.has-text-black-65 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-65-l)) !important;
}

.has-background-black-65 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-65-l)) !important;
}

.has-text-black-65-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-65-invert-l)) !important;
}

.has-background-black-65-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-65-invert-l)) !important;
}

.has-text-black-70 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-70-l)) !important;
}

.has-background-black-70 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-70-l)) !important;
}

.has-text-black-70-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-70-invert-l)) !important;
}

.has-background-black-70-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-70-invert-l)) !important;
}

.has-text-black-75 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-75-l)) !important;
}

.has-background-black-75 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-75-l)) !important;
}

.has-text-black-75-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-75-invert-l)) !important;
}

.has-background-black-75-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-75-invert-l)) !important;
}

.has-text-black-80 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-80-l)) !important;
}

.has-background-black-80 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-80-l)) !important;
}

.has-text-black-80-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-80-invert-l)) !important;
}

.has-background-black-80-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-80-invert-l)) !important;
}

.has-text-black-85 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-85-l)) !important;
}

.has-background-black-85 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-85-l)) !important;
}

.has-text-black-85-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-85-invert-l)) !important;
}

.has-background-black-85-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-85-invert-l)) !important;
}

.has-text-black-90 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-90-l)) !important;
}

.has-background-black-90 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-90-l)) !important;
}

.has-text-black-90-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-90-invert-l)) !important;
}

.has-background-black-90-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-90-invert-l)) !important;
}

.has-text-black-95 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-95-l)) !important;
}

.has-background-black-95 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-95-l)) !important;
}

.has-text-black-95-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-95-invert-l)) !important;
}

.has-background-black-95-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-95-invert-l)) !important;
}

.has-text-black-100 {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-100-l)) !important;
}

.has-background-black-100 {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-100-l)) !important;
}

.has-text-black-100-invert {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-100-invert-l)) !important;
}

.has-background-black-100-invert {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), var(--bulma-black-100-invert-l)) !important;
}

a.has-text-black:hover, a.has-text-black:focus-visible,
button.has-text-black:hover,
button.has-text-black:focus-visible,
has-text-black.is-hoverable:hover,
has-text-black.is-hoverable:focus-visible {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), calc(var(--bulma-black-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-black:active,
button.has-text-black:active,
has-text-black.is-hoverable:active {
  color: hsl(var(--bulma-black-h), var(--bulma-black-s), calc(var(--bulma-black-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-black:hover, a.has-background-black:focus-visible,
button.has-background-black:hover,
button.has-background-black:focus-visible,
has-background-black.is-hoverable:hover,
has-background-black.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), calc(var(--bulma-black-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-black:active,
button.has-background-black:active,
has-background-black.is-hoverable:active {
  background-color: hsl(var(--bulma-black-h), var(--bulma-black-s), calc(var(--bulma-black-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-black {
  --h: var(--bulma-black-h);
  --s: var(--bulma-black-s);
  --l: var(--bulma-black-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-black-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-black-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-black-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-black-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-black-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-black-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-black-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-black-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-black-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-black-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-black-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-black-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-black-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-black-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-black-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-black-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-black-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-black-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-black-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-black-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-black-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-light {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-l)) !important;
}

.has-background-light {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-l)) !important;
}

.has-text-light-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-invert-l)) !important;
}

.has-background-light-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-invert-l)) !important;
}

.has-text-light-on-scheme {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-on-scheme-l)) !important;
}

.has-background-light-on-scheme {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-on-scheme-l)) !important;
}

.has-text-light-light {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-light-l)) !important;
}

.has-background-light-light {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-light-l)) !important;
}

.has-text-light-light-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-light-invert-l)) !important;
}

.has-background-light-light-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-light-invert-l)) !important;
}

.has-text-light-dark {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-dark-l)) !important;
}

.has-background-light-dark {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-dark-l)) !important;
}

.has-text-light-dark-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-dark-invert-l)) !important;
}

.has-background-light-dark-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-dark-invert-l)) !important;
}

.has-text-light-soft {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-soft-l)) !important;
}

.has-background-light-soft {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-soft-l)) !important;
}

.has-text-light-bold {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-bold-l)) !important;
}

.has-background-light-bold {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-bold-l)) !important;
}

.has-text-light-soft-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-light-soft-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-light-bold-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-light-bold-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-light-00 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-00-l)) !important;
}

.has-background-light-00 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-00-l)) !important;
}

.has-text-light-00-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-00-invert-l)) !important;
}

.has-background-light-00-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-00-invert-l)) !important;
}

.has-text-light-05 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-05-l)) !important;
}

.has-background-light-05 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-05-l)) !important;
}

.has-text-light-05-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-05-invert-l)) !important;
}

.has-background-light-05-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-05-invert-l)) !important;
}

.has-text-light-10 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-10-l)) !important;
}

.has-background-light-10 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-10-l)) !important;
}

.has-text-light-10-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-10-invert-l)) !important;
}

.has-background-light-10-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-10-invert-l)) !important;
}

.has-text-light-15 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-15-l)) !important;
}

.has-background-light-15 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-15-l)) !important;
}

.has-text-light-15-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-15-invert-l)) !important;
}

.has-background-light-15-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-15-invert-l)) !important;
}

.has-text-light-20 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-20-l)) !important;
}

.has-background-light-20 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-20-l)) !important;
}

.has-text-light-20-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-20-invert-l)) !important;
}

.has-background-light-20-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-20-invert-l)) !important;
}

.has-text-light-25 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-25-l)) !important;
}

.has-background-light-25 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-25-l)) !important;
}

.has-text-light-25-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-25-invert-l)) !important;
}

.has-background-light-25-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-25-invert-l)) !important;
}

.has-text-light-30 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-30-l)) !important;
}

.has-background-light-30 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-30-l)) !important;
}

.has-text-light-30-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-30-invert-l)) !important;
}

.has-background-light-30-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-30-invert-l)) !important;
}

.has-text-light-35 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-35-l)) !important;
}

.has-background-light-35 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-35-l)) !important;
}

.has-text-light-35-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-35-invert-l)) !important;
}

.has-background-light-35-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-35-invert-l)) !important;
}

.has-text-light-40 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-40-l)) !important;
}

.has-background-light-40 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-40-l)) !important;
}

.has-text-light-40-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-40-invert-l)) !important;
}

.has-background-light-40-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-40-invert-l)) !important;
}

.has-text-light-45 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-45-l)) !important;
}

.has-background-light-45 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-45-l)) !important;
}

.has-text-light-45-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-45-invert-l)) !important;
}

.has-background-light-45-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-45-invert-l)) !important;
}

.has-text-light-50 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-50-l)) !important;
}

.has-background-light-50 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-50-l)) !important;
}

.has-text-light-50-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-50-invert-l)) !important;
}

.has-background-light-50-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-50-invert-l)) !important;
}

.has-text-light-55 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-55-l)) !important;
}

.has-background-light-55 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-55-l)) !important;
}

.has-text-light-55-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-55-invert-l)) !important;
}

.has-background-light-55-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-55-invert-l)) !important;
}

.has-text-light-60 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-60-l)) !important;
}

.has-background-light-60 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-60-l)) !important;
}

.has-text-light-60-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-60-invert-l)) !important;
}

.has-background-light-60-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-60-invert-l)) !important;
}

.has-text-light-65 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-65-l)) !important;
}

.has-background-light-65 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-65-l)) !important;
}

.has-text-light-65-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-65-invert-l)) !important;
}

.has-background-light-65-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-65-invert-l)) !important;
}

.has-text-light-70 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-70-l)) !important;
}

.has-background-light-70 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-70-l)) !important;
}

.has-text-light-70-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-70-invert-l)) !important;
}

.has-background-light-70-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-70-invert-l)) !important;
}

.has-text-light-75 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-75-l)) !important;
}

.has-background-light-75 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-75-l)) !important;
}

.has-text-light-75-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-75-invert-l)) !important;
}

.has-background-light-75-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-75-invert-l)) !important;
}

.has-text-light-80 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-80-l)) !important;
}

.has-background-light-80 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-80-l)) !important;
}

.has-text-light-80-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-80-invert-l)) !important;
}

.has-background-light-80-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-80-invert-l)) !important;
}

.has-text-light-85 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-85-l)) !important;
}

.has-background-light-85 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-85-l)) !important;
}

.has-text-light-85-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-85-invert-l)) !important;
}

.has-background-light-85-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-85-invert-l)) !important;
}

.has-text-light-90 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-90-l)) !important;
}

.has-background-light-90 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-90-l)) !important;
}

.has-text-light-90-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-90-invert-l)) !important;
}

.has-background-light-90-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-90-invert-l)) !important;
}

.has-text-light-95 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-95-l)) !important;
}

.has-background-light-95 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-95-l)) !important;
}

.has-text-light-95-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-95-invert-l)) !important;
}

.has-background-light-95-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-95-invert-l)) !important;
}

.has-text-light-100 {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-100-l)) !important;
}

.has-background-light-100 {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-100-l)) !important;
}

.has-text-light-100-invert {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-100-invert-l)) !important;
}

.has-background-light-100-invert {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), var(--bulma-light-100-invert-l)) !important;
}

a.has-text-light:hover, a.has-text-light:focus-visible,
button.has-text-light:hover,
button.has-text-light:focus-visible,
has-text-light.is-hoverable:hover,
has-text-light.is-hoverable:focus-visible {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), calc(var(--bulma-light-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-light:active,
button.has-text-light:active,
has-text-light.is-hoverable:active {
  color: hsl(var(--bulma-light-h), var(--bulma-light-s), calc(var(--bulma-light-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-light:hover, a.has-background-light:focus-visible,
button.has-background-light:hover,
button.has-background-light:focus-visible,
has-background-light.is-hoverable:hover,
has-background-light.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), calc(var(--bulma-light-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-light:active,
button.has-background-light:active,
has-background-light.is-hoverable:active {
  background-color: hsl(var(--bulma-light-h), var(--bulma-light-s), calc(var(--bulma-light-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-light {
  --h: var(--bulma-light-h);
  --s: var(--bulma-light-s);
  --l: var(--bulma-light-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-light-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-light-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-light-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-light-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-light-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-light-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-light-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-light-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-light-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-light-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-light-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-light-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-light-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-light-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-light-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-light-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-light-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-light-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-light-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-light-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-light-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-dark {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-l)) !important;
}

.has-background-dark {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-l)) !important;
}

.has-text-dark-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-invert-l)) !important;
}

.has-background-dark-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-invert-l)) !important;
}

.has-text-dark-on-scheme {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-on-scheme-l)) !important;
}

.has-background-dark-on-scheme {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-on-scheme-l)) !important;
}

.has-text-dark-light {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-light-l)) !important;
}

.has-background-dark-light {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-light-l)) !important;
}

.has-text-dark-light-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-light-invert-l)) !important;
}

.has-background-dark-light-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-light-invert-l)) !important;
}

.has-text-dark-dark {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-dark-l)) !important;
}

.has-background-dark-dark {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-dark-l)) !important;
}

.has-text-dark-dark-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-dark-invert-l)) !important;
}

.has-background-dark-dark-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-dark-invert-l)) !important;
}

.has-text-dark-soft {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-soft-l)) !important;
}

.has-background-dark-soft {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-soft-l)) !important;
}

.has-text-dark-bold {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-bold-l)) !important;
}

.has-background-dark-bold {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-bold-l)) !important;
}

.has-text-dark-soft-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-dark-soft-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-dark-bold-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-dark-bold-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-dark-00 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-00-l)) !important;
}

.has-background-dark-00 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-00-l)) !important;
}

.has-text-dark-00-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-00-invert-l)) !important;
}

.has-background-dark-00-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-00-invert-l)) !important;
}

.has-text-dark-05 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-05-l)) !important;
}

.has-background-dark-05 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-05-l)) !important;
}

.has-text-dark-05-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-05-invert-l)) !important;
}

.has-background-dark-05-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-05-invert-l)) !important;
}

.has-text-dark-10 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-10-l)) !important;
}

.has-background-dark-10 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-10-l)) !important;
}

.has-text-dark-10-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-10-invert-l)) !important;
}

.has-background-dark-10-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-10-invert-l)) !important;
}

.has-text-dark-15 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-15-l)) !important;
}

.has-background-dark-15 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-15-l)) !important;
}

.has-text-dark-15-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-15-invert-l)) !important;
}

.has-background-dark-15-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-15-invert-l)) !important;
}

.has-text-dark-20 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-20-l)) !important;
}

.has-background-dark-20 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-20-l)) !important;
}

.has-text-dark-20-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-20-invert-l)) !important;
}

.has-background-dark-20-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-20-invert-l)) !important;
}

.has-text-dark-25 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-25-l)) !important;
}

.has-background-dark-25 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-25-l)) !important;
}

.has-text-dark-25-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-25-invert-l)) !important;
}

.has-background-dark-25-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-25-invert-l)) !important;
}

.has-text-dark-30 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-30-l)) !important;
}

.has-background-dark-30 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-30-l)) !important;
}

.has-text-dark-30-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-30-invert-l)) !important;
}

.has-background-dark-30-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-30-invert-l)) !important;
}

.has-text-dark-35 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-35-l)) !important;
}

.has-background-dark-35 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-35-l)) !important;
}

.has-text-dark-35-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-35-invert-l)) !important;
}

.has-background-dark-35-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-35-invert-l)) !important;
}

.has-text-dark-40 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-40-l)) !important;
}

.has-background-dark-40 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-40-l)) !important;
}

.has-text-dark-40-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-40-invert-l)) !important;
}

.has-background-dark-40-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-40-invert-l)) !important;
}

.has-text-dark-45 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-45-l)) !important;
}

.has-background-dark-45 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-45-l)) !important;
}

.has-text-dark-45-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-45-invert-l)) !important;
}

.has-background-dark-45-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-45-invert-l)) !important;
}

.has-text-dark-50 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-50-l)) !important;
}

.has-background-dark-50 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-50-l)) !important;
}

.has-text-dark-50-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-50-invert-l)) !important;
}

.has-background-dark-50-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-50-invert-l)) !important;
}

.has-text-dark-55 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-55-l)) !important;
}

.has-background-dark-55 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-55-l)) !important;
}

.has-text-dark-55-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-55-invert-l)) !important;
}

.has-background-dark-55-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-55-invert-l)) !important;
}

.has-text-dark-60 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-60-l)) !important;
}

.has-background-dark-60 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-60-l)) !important;
}

.has-text-dark-60-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-60-invert-l)) !important;
}

.has-background-dark-60-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-60-invert-l)) !important;
}

.has-text-dark-65 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-65-l)) !important;
}

.has-background-dark-65 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-65-l)) !important;
}

.has-text-dark-65-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-65-invert-l)) !important;
}

.has-background-dark-65-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-65-invert-l)) !important;
}

.has-text-dark-70 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-70-l)) !important;
}

.has-background-dark-70 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-70-l)) !important;
}

.has-text-dark-70-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-70-invert-l)) !important;
}

.has-background-dark-70-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-70-invert-l)) !important;
}

.has-text-dark-75 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-75-l)) !important;
}

.has-background-dark-75 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-75-l)) !important;
}

.has-text-dark-75-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-75-invert-l)) !important;
}

.has-background-dark-75-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-75-invert-l)) !important;
}

.has-text-dark-80 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-80-l)) !important;
}

.has-background-dark-80 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-80-l)) !important;
}

.has-text-dark-80-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-80-invert-l)) !important;
}

.has-background-dark-80-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-80-invert-l)) !important;
}

.has-text-dark-85 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-85-l)) !important;
}

.has-background-dark-85 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-85-l)) !important;
}

.has-text-dark-85-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-85-invert-l)) !important;
}

.has-background-dark-85-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-85-invert-l)) !important;
}

.has-text-dark-90 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-90-l)) !important;
}

.has-background-dark-90 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-90-l)) !important;
}

.has-text-dark-90-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-90-invert-l)) !important;
}

.has-background-dark-90-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-90-invert-l)) !important;
}

.has-text-dark-95 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-95-l)) !important;
}

.has-background-dark-95 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-95-l)) !important;
}

.has-text-dark-95-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-95-invert-l)) !important;
}

.has-background-dark-95-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-95-invert-l)) !important;
}

.has-text-dark-100 {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-100-l)) !important;
}

.has-background-dark-100 {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-100-l)) !important;
}

.has-text-dark-100-invert {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-100-invert-l)) !important;
}

.has-background-dark-100-invert {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), var(--bulma-dark-100-invert-l)) !important;
}

a.has-text-dark:hover, a.has-text-dark:focus-visible,
button.has-text-dark:hover,
button.has-text-dark:focus-visible,
has-text-dark.is-hoverable:hover,
has-text-dark.is-hoverable:focus-visible {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), calc(var(--bulma-dark-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-dark:active,
button.has-text-dark:active,
has-text-dark.is-hoverable:active {
  color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), calc(var(--bulma-dark-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-dark:hover, a.has-background-dark:focus-visible,
button.has-background-dark:hover,
button.has-background-dark:focus-visible,
has-background-dark.is-hoverable:hover,
has-background-dark.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), calc(var(--bulma-dark-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-dark:active,
button.has-background-dark:active,
has-background-dark.is-hoverable:active {
  background-color: hsl(var(--bulma-dark-h), var(--bulma-dark-s), calc(var(--bulma-dark-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-dark {
  --h: var(--bulma-dark-h);
  --s: var(--bulma-dark-s);
  --l: var(--bulma-dark-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-dark-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-dark-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-dark-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-dark-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-dark-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-dark-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-dark-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-dark-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-dark-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-dark-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-dark-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-dark-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-dark-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-dark-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-dark-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-dark-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-dark-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-dark-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-dark-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-dark-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-dark-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-text {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-l)) !important;
}

.has-background-text {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-l)) !important;
}

.has-text-text-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-invert-l)) !important;
}

.has-background-text-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-invert-l)) !important;
}

.has-text-text-on-scheme {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-on-scheme-l)) !important;
}

.has-background-text-on-scheme {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-on-scheme-l)) !important;
}

.has-text-text-light {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-light-l)) !important;
}

.has-background-text-light {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-light-l)) !important;
}

.has-text-text-light-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-light-invert-l)) !important;
}

.has-background-text-light-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-light-invert-l)) !important;
}

.has-text-text-dark {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-dark-l)) !important;
}

.has-background-text-dark {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-dark-l)) !important;
}

.has-text-text-dark-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-dark-invert-l)) !important;
}

.has-background-text-dark-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-dark-invert-l)) !important;
}

.has-text-text-soft {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-soft-l)) !important;
}

.has-background-text-soft {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-soft-l)) !important;
}

.has-text-text-bold {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-bold-l)) !important;
}

.has-background-text-bold {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-bold-l)) !important;
}

.has-text-text-soft-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-text-soft-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-text-bold-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-text-bold-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-text-00 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-00-l)) !important;
}

.has-background-text-00 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-00-l)) !important;
}

.has-text-text-00-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-00-invert-l)) !important;
}

.has-background-text-00-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-00-invert-l)) !important;
}

.has-text-text-05 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-05-l)) !important;
}

.has-background-text-05 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-05-l)) !important;
}

.has-text-text-05-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-05-invert-l)) !important;
}

.has-background-text-05-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-05-invert-l)) !important;
}

.has-text-text-10 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-10-l)) !important;
}

.has-background-text-10 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-10-l)) !important;
}

.has-text-text-10-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-10-invert-l)) !important;
}

.has-background-text-10-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-10-invert-l)) !important;
}

.has-text-text-15 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-15-l)) !important;
}

.has-background-text-15 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-15-l)) !important;
}

.has-text-text-15-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-15-invert-l)) !important;
}

.has-background-text-15-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-15-invert-l)) !important;
}

.has-text-text-20 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-20-l)) !important;
}

.has-background-text-20 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-20-l)) !important;
}

.has-text-text-20-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-20-invert-l)) !important;
}

.has-background-text-20-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-20-invert-l)) !important;
}

.has-text-text-25 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-25-l)) !important;
}

.has-background-text-25 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-25-l)) !important;
}

.has-text-text-25-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-25-invert-l)) !important;
}

.has-background-text-25-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-25-invert-l)) !important;
}

.has-text-text-30 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-30-l)) !important;
}

.has-background-text-30 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-30-l)) !important;
}

.has-text-text-30-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-30-invert-l)) !important;
}

.has-background-text-30-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-30-invert-l)) !important;
}

.has-text-text-35 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-35-l)) !important;
}

.has-background-text-35 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-35-l)) !important;
}

.has-text-text-35-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-35-invert-l)) !important;
}

.has-background-text-35-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-35-invert-l)) !important;
}

.has-text-text-40 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-40-l)) !important;
}

.has-background-text-40 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-40-l)) !important;
}

.has-text-text-40-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-40-invert-l)) !important;
}

.has-background-text-40-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-40-invert-l)) !important;
}

.has-text-text-45 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-45-l)) !important;
}

.has-background-text-45 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-45-l)) !important;
}

.has-text-text-45-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-45-invert-l)) !important;
}

.has-background-text-45-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-45-invert-l)) !important;
}

.has-text-text-50 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-50-l)) !important;
}

.has-background-text-50 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-50-l)) !important;
}

.has-text-text-50-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-50-invert-l)) !important;
}

.has-background-text-50-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-50-invert-l)) !important;
}

.has-text-text-55 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-55-l)) !important;
}

.has-background-text-55 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-55-l)) !important;
}

.has-text-text-55-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-55-invert-l)) !important;
}

.has-background-text-55-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-55-invert-l)) !important;
}

.has-text-text-60 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-60-l)) !important;
}

.has-background-text-60 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-60-l)) !important;
}

.has-text-text-60-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-60-invert-l)) !important;
}

.has-background-text-60-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-60-invert-l)) !important;
}

.has-text-text-65 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-65-l)) !important;
}

.has-background-text-65 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-65-l)) !important;
}

.has-text-text-65-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-65-invert-l)) !important;
}

.has-background-text-65-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-65-invert-l)) !important;
}

.has-text-text-70 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-70-l)) !important;
}

.has-background-text-70 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-70-l)) !important;
}

.has-text-text-70-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-70-invert-l)) !important;
}

.has-background-text-70-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-70-invert-l)) !important;
}

.has-text-text-75 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-75-l)) !important;
}

.has-background-text-75 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-75-l)) !important;
}

.has-text-text-75-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-75-invert-l)) !important;
}

.has-background-text-75-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-75-invert-l)) !important;
}

.has-text-text-80 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-80-l)) !important;
}

.has-background-text-80 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-80-l)) !important;
}

.has-text-text-80-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-80-invert-l)) !important;
}

.has-background-text-80-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-80-invert-l)) !important;
}

.has-text-text-85 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-85-l)) !important;
}

.has-background-text-85 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-85-l)) !important;
}

.has-text-text-85-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-85-invert-l)) !important;
}

.has-background-text-85-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-85-invert-l)) !important;
}

.has-text-text-90 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-90-l)) !important;
}

.has-background-text-90 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-90-l)) !important;
}

.has-text-text-90-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-90-invert-l)) !important;
}

.has-background-text-90-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-90-invert-l)) !important;
}

.has-text-text-95 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-95-l)) !important;
}

.has-background-text-95 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-95-l)) !important;
}

.has-text-text-95-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-95-invert-l)) !important;
}

.has-background-text-95-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-95-invert-l)) !important;
}

.has-text-text-100 {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-100-l)) !important;
}

.has-background-text-100 {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-100-l)) !important;
}

.has-text-text-100-invert {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-100-invert-l)) !important;
}

.has-background-text-100-invert {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-100-invert-l)) !important;
}

a.has-text-text:hover, a.has-text-text:focus-visible,
button.has-text-text:hover,
button.has-text-text:focus-visible,
has-text-text.is-hoverable:hover,
has-text-text.is-hoverable:focus-visible {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), calc(var(--bulma-text-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-text:active,
button.has-text-text:active,
has-text-text.is-hoverable:active {
  color: hsl(var(--bulma-text-h), var(--bulma-text-s), calc(var(--bulma-text-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-text:hover, a.has-background-text:focus-visible,
button.has-background-text:hover,
button.has-background-text:focus-visible,
has-background-text.is-hoverable:hover,
has-background-text.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), calc(var(--bulma-text-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-text:active,
button.has-background-text:active,
has-background-text.is-hoverable:active {
  background-color: hsl(var(--bulma-text-h), var(--bulma-text-s), calc(var(--bulma-text-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-text {
  --h: var(--bulma-text-h);
  --s: var(--bulma-text-s);
  --l: var(--bulma-text-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-text-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-text-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-text-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-text-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-text-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-text-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-text-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-text-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-text-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-text-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-text-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-text-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-text-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-text-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-text-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-text-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-text-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-text-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-text-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-text-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-text-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-primary {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-l)) !important;
}

.has-background-primary {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-l)) !important;
}

.has-text-primary-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-invert-l)) !important;
}

.has-background-primary-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-invert-l)) !important;
}

.has-text-primary-on-scheme {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-on-scheme-l)) !important;
}

.has-background-primary-on-scheme {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-on-scheme-l)) !important;
}

.has-text-primary-light {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-light-l)) !important;
}

.has-background-primary-light {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-light-l)) !important;
}

.has-text-primary-light-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-light-invert-l)) !important;
}

.has-background-primary-light-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-light-invert-l)) !important;
}

.has-text-primary-dark {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-dark-l)) !important;
}

.has-background-primary-dark {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-dark-l)) !important;
}

.has-text-primary-dark-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-dark-invert-l)) !important;
}

.has-background-primary-dark-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-dark-invert-l)) !important;
}

.has-text-primary-soft {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-soft-l)) !important;
}

.has-background-primary-soft {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-soft-l)) !important;
}

.has-text-primary-bold {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-bold-l)) !important;
}

.has-background-primary-bold {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-bold-l)) !important;
}

.has-text-primary-soft-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-primary-soft-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-primary-bold-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-primary-bold-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-primary-00 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-00-l)) !important;
}

.has-background-primary-00 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-00-l)) !important;
}

.has-text-primary-00-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-00-invert-l)) !important;
}

.has-background-primary-00-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-00-invert-l)) !important;
}

.has-text-primary-05 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-05-l)) !important;
}

.has-background-primary-05 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-05-l)) !important;
}

.has-text-primary-05-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-05-invert-l)) !important;
}

.has-background-primary-05-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-05-invert-l)) !important;
}

.has-text-primary-10 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-10-l)) !important;
}

.has-background-primary-10 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-10-l)) !important;
}

.has-text-primary-10-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-10-invert-l)) !important;
}

.has-background-primary-10-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-10-invert-l)) !important;
}

.has-text-primary-15 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-15-l)) !important;
}

.has-background-primary-15 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-15-l)) !important;
}

.has-text-primary-15-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-15-invert-l)) !important;
}

.has-background-primary-15-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-15-invert-l)) !important;
}

.has-text-primary-20 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-20-l)) !important;
}

.has-background-primary-20 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-20-l)) !important;
}

.has-text-primary-20-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-20-invert-l)) !important;
}

.has-background-primary-20-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-20-invert-l)) !important;
}

.has-text-primary-25 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-25-l)) !important;
}

.has-background-primary-25 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-25-l)) !important;
}

.has-text-primary-25-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-25-invert-l)) !important;
}

.has-background-primary-25-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-25-invert-l)) !important;
}

.has-text-primary-30 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-30-l)) !important;
}

.has-background-primary-30 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-30-l)) !important;
}

.has-text-primary-30-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-30-invert-l)) !important;
}

.has-background-primary-30-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-30-invert-l)) !important;
}

.has-text-primary-35 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-35-l)) !important;
}

.has-background-primary-35 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-35-l)) !important;
}

.has-text-primary-35-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-35-invert-l)) !important;
}

.has-background-primary-35-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-35-invert-l)) !important;
}

.has-text-primary-40 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-40-l)) !important;
}

.has-background-primary-40 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-40-l)) !important;
}

.has-text-primary-40-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-40-invert-l)) !important;
}

.has-background-primary-40-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-40-invert-l)) !important;
}

.has-text-primary-45 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-45-l)) !important;
}

.has-background-primary-45 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-45-l)) !important;
}

.has-text-primary-45-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-45-invert-l)) !important;
}

.has-background-primary-45-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-45-invert-l)) !important;
}

.has-text-primary-50 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-50-l)) !important;
}

.has-background-primary-50 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-50-l)) !important;
}

.has-text-primary-50-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-50-invert-l)) !important;
}

.has-background-primary-50-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-50-invert-l)) !important;
}

.has-text-primary-55 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-55-l)) !important;
}

.has-background-primary-55 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-55-l)) !important;
}

.has-text-primary-55-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-55-invert-l)) !important;
}

.has-background-primary-55-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-55-invert-l)) !important;
}

.has-text-primary-60 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-60-l)) !important;
}

.has-background-primary-60 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-60-l)) !important;
}

.has-text-primary-60-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-60-invert-l)) !important;
}

.has-background-primary-60-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-60-invert-l)) !important;
}

.has-text-primary-65 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-65-l)) !important;
}

.has-background-primary-65 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-65-l)) !important;
}

.has-text-primary-65-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-65-invert-l)) !important;
}

.has-background-primary-65-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-65-invert-l)) !important;
}

.has-text-primary-70 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-70-l)) !important;
}

.has-background-primary-70 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-70-l)) !important;
}

.has-text-primary-70-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-70-invert-l)) !important;
}

.has-background-primary-70-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-70-invert-l)) !important;
}

.has-text-primary-75 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-75-l)) !important;
}

.has-background-primary-75 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-75-l)) !important;
}

.has-text-primary-75-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-75-invert-l)) !important;
}

.has-background-primary-75-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-75-invert-l)) !important;
}

.has-text-primary-80 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-80-l)) !important;
}

.has-background-primary-80 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-80-l)) !important;
}

.has-text-primary-80-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-80-invert-l)) !important;
}

.has-background-primary-80-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-80-invert-l)) !important;
}

.has-text-primary-85 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-85-l)) !important;
}

.has-background-primary-85 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-85-l)) !important;
}

.has-text-primary-85-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-85-invert-l)) !important;
}

.has-background-primary-85-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-85-invert-l)) !important;
}

.has-text-primary-90 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-90-l)) !important;
}

.has-background-primary-90 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-90-l)) !important;
}

.has-text-primary-90-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-90-invert-l)) !important;
}

.has-background-primary-90-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-90-invert-l)) !important;
}

.has-text-primary-95 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-95-l)) !important;
}

.has-background-primary-95 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-95-l)) !important;
}

.has-text-primary-95-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-95-invert-l)) !important;
}

.has-background-primary-95-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-95-invert-l)) !important;
}

.has-text-primary-100 {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-100-l)) !important;
}

.has-background-primary-100 {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-100-l)) !important;
}

.has-text-primary-100-invert {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-100-invert-l)) !important;
}

.has-background-primary-100-invert {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), var(--bulma-primary-100-invert-l)) !important;
}

a.has-text-primary:hover, a.has-text-primary:focus-visible,
button.has-text-primary:hover,
button.has-text-primary:focus-visible,
has-text-primary.is-hoverable:hover,
has-text-primary.is-hoverable:focus-visible {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), calc(var(--bulma-primary-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-primary:active,
button.has-text-primary:active,
has-text-primary.is-hoverable:active {
  color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), calc(var(--bulma-primary-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-primary:hover, a.has-background-primary:focus-visible,
button.has-background-primary:hover,
button.has-background-primary:focus-visible,
has-background-primary.is-hoverable:hover,
has-background-primary.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), calc(var(--bulma-primary-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-primary:active,
button.has-background-primary:active,
has-background-primary.is-hoverable:active {
  background-color: hsl(var(--bulma-primary-h), var(--bulma-primary-s), calc(var(--bulma-primary-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-primary {
  --h: var(--bulma-primary-h);
  --s: var(--bulma-primary-s);
  --l: var(--bulma-primary-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-primary-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-primary-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-primary-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-primary-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-primary-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-primary-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-primary-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-primary-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-primary-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-primary-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-primary-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-primary-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-primary-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-primary-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-primary-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-primary-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-primary-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-primary-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-primary-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-primary-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-primary-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-link {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-l)) !important;
}

.has-background-link {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-l)) !important;
}

.has-text-link-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-invert-l)) !important;
}

.has-background-link-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-invert-l)) !important;
}

.has-text-link-on-scheme {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-on-scheme-l)) !important;
}

.has-background-link-on-scheme {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-on-scheme-l)) !important;
}

.has-text-link-light {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-light-l)) !important;
}

.has-background-link-light {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-light-l)) !important;
}

.has-text-link-light-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-light-invert-l)) !important;
}

.has-background-link-light-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-light-invert-l)) !important;
}

.has-text-link-dark {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-dark-l)) !important;
}

.has-background-link-dark {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-dark-l)) !important;
}

.has-text-link-dark-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-dark-invert-l)) !important;
}

.has-background-link-dark-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-dark-invert-l)) !important;
}

.has-text-link-soft {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-soft-l)) !important;
}

.has-background-link-soft {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-soft-l)) !important;
}

.has-text-link-bold {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-bold-l)) !important;
}

.has-background-link-bold {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-bold-l)) !important;
}

.has-text-link-soft-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-link-soft-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-link-bold-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-link-bold-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-link-00 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-00-l)) !important;
}

.has-background-link-00 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-00-l)) !important;
}

.has-text-link-00-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-00-invert-l)) !important;
}

.has-background-link-00-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-00-invert-l)) !important;
}

.has-text-link-05 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-05-l)) !important;
}

.has-background-link-05 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-05-l)) !important;
}

.has-text-link-05-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-05-invert-l)) !important;
}

.has-background-link-05-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-05-invert-l)) !important;
}

.has-text-link-10 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-10-l)) !important;
}

.has-background-link-10 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-10-l)) !important;
}

.has-text-link-10-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-10-invert-l)) !important;
}

.has-background-link-10-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-10-invert-l)) !important;
}

.has-text-link-15 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-15-l)) !important;
}

.has-background-link-15 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-15-l)) !important;
}

.has-text-link-15-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-15-invert-l)) !important;
}

.has-background-link-15-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-15-invert-l)) !important;
}

.has-text-link-20 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-20-l)) !important;
}

.has-background-link-20 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-20-l)) !important;
}

.has-text-link-20-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-20-invert-l)) !important;
}

.has-background-link-20-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-20-invert-l)) !important;
}

.has-text-link-25 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-25-l)) !important;
}

.has-background-link-25 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-25-l)) !important;
}

.has-text-link-25-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-25-invert-l)) !important;
}

.has-background-link-25-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-25-invert-l)) !important;
}

.has-text-link-30 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-30-l)) !important;
}

.has-background-link-30 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-30-l)) !important;
}

.has-text-link-30-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-30-invert-l)) !important;
}

.has-background-link-30-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-30-invert-l)) !important;
}

.has-text-link-35 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-35-l)) !important;
}

.has-background-link-35 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-35-l)) !important;
}

.has-text-link-35-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-35-invert-l)) !important;
}

.has-background-link-35-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-35-invert-l)) !important;
}

.has-text-link-40 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-40-l)) !important;
}

.has-background-link-40 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-40-l)) !important;
}

.has-text-link-40-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-40-invert-l)) !important;
}

.has-background-link-40-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-40-invert-l)) !important;
}

.has-text-link-45 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-45-l)) !important;
}

.has-background-link-45 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-45-l)) !important;
}

.has-text-link-45-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-45-invert-l)) !important;
}

.has-background-link-45-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-45-invert-l)) !important;
}

.has-text-link-50 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-50-l)) !important;
}

.has-background-link-50 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-50-l)) !important;
}

.has-text-link-50-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-50-invert-l)) !important;
}

.has-background-link-50-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-50-invert-l)) !important;
}

.has-text-link-55 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-55-l)) !important;
}

.has-background-link-55 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-55-l)) !important;
}

.has-text-link-55-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-55-invert-l)) !important;
}

.has-background-link-55-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-55-invert-l)) !important;
}

.has-text-link-60 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-60-l)) !important;
}

.has-background-link-60 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-60-l)) !important;
}

.has-text-link-60-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-60-invert-l)) !important;
}

.has-background-link-60-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-60-invert-l)) !important;
}

.has-text-link-65 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-65-l)) !important;
}

.has-background-link-65 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-65-l)) !important;
}

.has-text-link-65-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-65-invert-l)) !important;
}

.has-background-link-65-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-65-invert-l)) !important;
}

.has-text-link-70 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-70-l)) !important;
}

.has-background-link-70 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-70-l)) !important;
}

.has-text-link-70-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-70-invert-l)) !important;
}

.has-background-link-70-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-70-invert-l)) !important;
}

.has-text-link-75 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-75-l)) !important;
}

.has-background-link-75 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-75-l)) !important;
}

.has-text-link-75-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-75-invert-l)) !important;
}

.has-background-link-75-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-75-invert-l)) !important;
}

.has-text-link-80 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-80-l)) !important;
}

.has-background-link-80 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-80-l)) !important;
}

.has-text-link-80-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-80-invert-l)) !important;
}

.has-background-link-80-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-80-invert-l)) !important;
}

.has-text-link-85 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-85-l)) !important;
}

.has-background-link-85 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-85-l)) !important;
}

.has-text-link-85-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-85-invert-l)) !important;
}

.has-background-link-85-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-85-invert-l)) !important;
}

.has-text-link-90 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-90-l)) !important;
}

.has-background-link-90 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-90-l)) !important;
}

.has-text-link-90-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-90-invert-l)) !important;
}

.has-background-link-90-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-90-invert-l)) !important;
}

.has-text-link-95 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-95-l)) !important;
}

.has-background-link-95 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-95-l)) !important;
}

.has-text-link-95-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-95-invert-l)) !important;
}

.has-background-link-95-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-95-invert-l)) !important;
}

.has-text-link-100 {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-100-l)) !important;
}

.has-background-link-100 {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-100-l)) !important;
}

.has-text-link-100-invert {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-100-invert-l)) !important;
}

.has-background-link-100-invert {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-100-invert-l)) !important;
}

a.has-text-link:hover, a.has-text-link:focus-visible,
button.has-text-link:hover,
button.has-text-link:focus-visible,
has-text-link.is-hoverable:hover,
has-text-link.is-hoverable:focus-visible {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), calc(var(--bulma-link-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-link:active,
button.has-text-link:active,
has-text-link.is-hoverable:active {
  color: hsl(var(--bulma-link-h), var(--bulma-link-s), calc(var(--bulma-link-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-link:hover, a.has-background-link:focus-visible,
button.has-background-link:hover,
button.has-background-link:focus-visible,
has-background-link.is-hoverable:hover,
has-background-link.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), calc(var(--bulma-link-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-link:active,
button.has-background-link:active,
has-background-link.is-hoverable:active {
  background-color: hsl(var(--bulma-link-h), var(--bulma-link-s), calc(var(--bulma-link-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-link {
  --h: var(--bulma-link-h);
  --s: var(--bulma-link-s);
  --l: var(--bulma-link-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-link-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-link-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-link-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-link-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-link-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-link-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-link-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-link-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-link-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-link-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-link-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-link-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-link-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-link-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-link-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-link-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-link-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-link-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-link-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-link-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-link-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-info {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-l)) !important;
}

.has-background-info {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-l)) !important;
}

.has-text-info-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-invert-l)) !important;
}

.has-background-info-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-invert-l)) !important;
}

.has-text-info-on-scheme {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-on-scheme-l)) !important;
}

.has-background-info-on-scheme {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-on-scheme-l)) !important;
}

.has-text-info-light {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-light-l)) !important;
}

.has-background-info-light {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-light-l)) !important;
}

.has-text-info-light-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-light-invert-l)) !important;
}

.has-background-info-light-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-light-invert-l)) !important;
}

.has-text-info-dark {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-dark-l)) !important;
}

.has-background-info-dark {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-dark-l)) !important;
}

.has-text-info-dark-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-dark-invert-l)) !important;
}

.has-background-info-dark-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-dark-invert-l)) !important;
}

.has-text-info-soft {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-soft-l)) !important;
}

.has-background-info-soft {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-soft-l)) !important;
}

.has-text-info-bold {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-bold-l)) !important;
}

.has-background-info-bold {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-bold-l)) !important;
}

.has-text-info-soft-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-info-soft-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-info-bold-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-info-bold-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-info-00 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-00-l)) !important;
}

.has-background-info-00 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-00-l)) !important;
}

.has-text-info-00-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-00-invert-l)) !important;
}

.has-background-info-00-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-00-invert-l)) !important;
}

.has-text-info-05 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-05-l)) !important;
}

.has-background-info-05 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-05-l)) !important;
}

.has-text-info-05-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-05-invert-l)) !important;
}

.has-background-info-05-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-05-invert-l)) !important;
}

.has-text-info-10 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-10-l)) !important;
}

.has-background-info-10 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-10-l)) !important;
}

.has-text-info-10-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-10-invert-l)) !important;
}

.has-background-info-10-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-10-invert-l)) !important;
}

.has-text-info-15 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-15-l)) !important;
}

.has-background-info-15 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-15-l)) !important;
}

.has-text-info-15-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-15-invert-l)) !important;
}

.has-background-info-15-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-15-invert-l)) !important;
}

.has-text-info-20 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-20-l)) !important;
}

.has-background-info-20 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-20-l)) !important;
}

.has-text-info-20-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-20-invert-l)) !important;
}

.has-background-info-20-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-20-invert-l)) !important;
}

.has-text-info-25 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-25-l)) !important;
}

.has-background-info-25 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-25-l)) !important;
}

.has-text-info-25-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-25-invert-l)) !important;
}

.has-background-info-25-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-25-invert-l)) !important;
}

.has-text-info-30 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-30-l)) !important;
}

.has-background-info-30 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-30-l)) !important;
}

.has-text-info-30-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-30-invert-l)) !important;
}

.has-background-info-30-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-30-invert-l)) !important;
}

.has-text-info-35 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-35-l)) !important;
}

.has-background-info-35 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-35-l)) !important;
}

.has-text-info-35-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-35-invert-l)) !important;
}

.has-background-info-35-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-35-invert-l)) !important;
}

.has-text-info-40 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-40-l)) !important;
}

.has-background-info-40 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-40-l)) !important;
}

.has-text-info-40-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-40-invert-l)) !important;
}

.has-background-info-40-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-40-invert-l)) !important;
}

.has-text-info-45 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-45-l)) !important;
}

.has-background-info-45 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-45-l)) !important;
}

.has-text-info-45-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-45-invert-l)) !important;
}

.has-background-info-45-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-45-invert-l)) !important;
}

.has-text-info-50 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-50-l)) !important;
}

.has-background-info-50 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-50-l)) !important;
}

.has-text-info-50-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-50-invert-l)) !important;
}

.has-background-info-50-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-50-invert-l)) !important;
}

.has-text-info-55 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-55-l)) !important;
}

.has-background-info-55 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-55-l)) !important;
}

.has-text-info-55-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-55-invert-l)) !important;
}

.has-background-info-55-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-55-invert-l)) !important;
}

.has-text-info-60 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-60-l)) !important;
}

.has-background-info-60 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-60-l)) !important;
}

.has-text-info-60-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-60-invert-l)) !important;
}

.has-background-info-60-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-60-invert-l)) !important;
}

.has-text-info-65 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-65-l)) !important;
}

.has-background-info-65 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-65-l)) !important;
}

.has-text-info-65-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-65-invert-l)) !important;
}

.has-background-info-65-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-65-invert-l)) !important;
}

.has-text-info-70 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-70-l)) !important;
}

.has-background-info-70 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-70-l)) !important;
}

.has-text-info-70-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-70-invert-l)) !important;
}

.has-background-info-70-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-70-invert-l)) !important;
}

.has-text-info-75 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-75-l)) !important;
}

.has-background-info-75 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-75-l)) !important;
}

.has-text-info-75-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-75-invert-l)) !important;
}

.has-background-info-75-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-75-invert-l)) !important;
}

.has-text-info-80 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-80-l)) !important;
}

.has-background-info-80 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-80-l)) !important;
}

.has-text-info-80-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-80-invert-l)) !important;
}

.has-background-info-80-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-80-invert-l)) !important;
}

.has-text-info-85 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-85-l)) !important;
}

.has-background-info-85 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-85-l)) !important;
}

.has-text-info-85-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-85-invert-l)) !important;
}

.has-background-info-85-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-85-invert-l)) !important;
}

.has-text-info-90 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-90-l)) !important;
}

.has-background-info-90 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-90-l)) !important;
}

.has-text-info-90-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-90-invert-l)) !important;
}

.has-background-info-90-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-90-invert-l)) !important;
}

.has-text-info-95 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-95-l)) !important;
}

.has-background-info-95 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-95-l)) !important;
}

.has-text-info-95-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-95-invert-l)) !important;
}

.has-background-info-95-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-95-invert-l)) !important;
}

.has-text-info-100 {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-100-l)) !important;
}

.has-background-info-100 {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-100-l)) !important;
}

.has-text-info-100-invert {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-100-invert-l)) !important;
}

.has-background-info-100-invert {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), var(--bulma-info-100-invert-l)) !important;
}

a.has-text-info:hover, a.has-text-info:focus-visible,
button.has-text-info:hover,
button.has-text-info:focus-visible,
has-text-info.is-hoverable:hover,
has-text-info.is-hoverable:focus-visible {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), calc(var(--bulma-info-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-info:active,
button.has-text-info:active,
has-text-info.is-hoverable:active {
  color: hsl(var(--bulma-info-h), var(--bulma-info-s), calc(var(--bulma-info-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-info:hover, a.has-background-info:focus-visible,
button.has-background-info:hover,
button.has-background-info:focus-visible,
has-background-info.is-hoverable:hover,
has-background-info.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), calc(var(--bulma-info-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-info:active,
button.has-background-info:active,
has-background-info.is-hoverable:active {
  background-color: hsl(var(--bulma-info-h), var(--bulma-info-s), calc(var(--bulma-info-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-info {
  --h: var(--bulma-info-h);
  --s: var(--bulma-info-s);
  --l: var(--bulma-info-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-info-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-info-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-info-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-info-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-info-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-info-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-info-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-info-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-info-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-info-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-info-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-info-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-info-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-info-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-info-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-info-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-info-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-info-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-info-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-info-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-info-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-success {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-l)) !important;
}

.has-background-success {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-l)) !important;
}

.has-text-success-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-invert-l)) !important;
}

.has-background-success-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-invert-l)) !important;
}

.has-text-success-on-scheme {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-on-scheme-l)) !important;
}

.has-background-success-on-scheme {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-on-scheme-l)) !important;
}

.has-text-success-light {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-light-l)) !important;
}

.has-background-success-light {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-light-l)) !important;
}

.has-text-success-light-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-light-invert-l)) !important;
}

.has-background-success-light-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-light-invert-l)) !important;
}

.has-text-success-dark {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-dark-l)) !important;
}

.has-background-success-dark {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-dark-l)) !important;
}

.has-text-success-dark-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-dark-invert-l)) !important;
}

.has-background-success-dark-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-dark-invert-l)) !important;
}

.has-text-success-soft {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-soft-l)) !important;
}

.has-background-success-soft {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-soft-l)) !important;
}

.has-text-success-bold {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-bold-l)) !important;
}

.has-background-success-bold {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-bold-l)) !important;
}

.has-text-success-soft-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-success-soft-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-success-bold-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-success-bold-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-success-00 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-00-l)) !important;
}

.has-background-success-00 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-00-l)) !important;
}

.has-text-success-00-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-00-invert-l)) !important;
}

.has-background-success-00-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-00-invert-l)) !important;
}

.has-text-success-05 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-05-l)) !important;
}

.has-background-success-05 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-05-l)) !important;
}

.has-text-success-05-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-05-invert-l)) !important;
}

.has-background-success-05-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-05-invert-l)) !important;
}

.has-text-success-10 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-10-l)) !important;
}

.has-background-success-10 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-10-l)) !important;
}

.has-text-success-10-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-10-invert-l)) !important;
}

.has-background-success-10-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-10-invert-l)) !important;
}

.has-text-success-15 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-15-l)) !important;
}

.has-background-success-15 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-15-l)) !important;
}

.has-text-success-15-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-15-invert-l)) !important;
}

.has-background-success-15-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-15-invert-l)) !important;
}

.has-text-success-20 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-20-l)) !important;
}

.has-background-success-20 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-20-l)) !important;
}

.has-text-success-20-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-20-invert-l)) !important;
}

.has-background-success-20-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-20-invert-l)) !important;
}

.has-text-success-25 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-25-l)) !important;
}

.has-background-success-25 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-25-l)) !important;
}

.has-text-success-25-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-25-invert-l)) !important;
}

.has-background-success-25-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-25-invert-l)) !important;
}

.has-text-success-30 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-30-l)) !important;
}

.has-background-success-30 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-30-l)) !important;
}

.has-text-success-30-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-30-invert-l)) !important;
}

.has-background-success-30-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-30-invert-l)) !important;
}

.has-text-success-35 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-35-l)) !important;
}

.has-background-success-35 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-35-l)) !important;
}

.has-text-success-35-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-35-invert-l)) !important;
}

.has-background-success-35-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-35-invert-l)) !important;
}

.has-text-success-40 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-40-l)) !important;
}

.has-background-success-40 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-40-l)) !important;
}

.has-text-success-40-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-40-invert-l)) !important;
}

.has-background-success-40-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-40-invert-l)) !important;
}

.has-text-success-45 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-45-l)) !important;
}

.has-background-success-45 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-45-l)) !important;
}

.has-text-success-45-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-45-invert-l)) !important;
}

.has-background-success-45-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-45-invert-l)) !important;
}

.has-text-success-50 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-50-l)) !important;
}

.has-background-success-50 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-50-l)) !important;
}

.has-text-success-50-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-50-invert-l)) !important;
}

.has-background-success-50-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-50-invert-l)) !important;
}

.has-text-success-55 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-55-l)) !important;
}

.has-background-success-55 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-55-l)) !important;
}

.has-text-success-55-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-55-invert-l)) !important;
}

.has-background-success-55-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-55-invert-l)) !important;
}

.has-text-success-60 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-60-l)) !important;
}

.has-background-success-60 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-60-l)) !important;
}

.has-text-success-60-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-60-invert-l)) !important;
}

.has-background-success-60-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-60-invert-l)) !important;
}

.has-text-success-65 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-65-l)) !important;
}

.has-background-success-65 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-65-l)) !important;
}

.has-text-success-65-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-65-invert-l)) !important;
}

.has-background-success-65-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-65-invert-l)) !important;
}

.has-text-success-70 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-70-l)) !important;
}

.has-background-success-70 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-70-l)) !important;
}

.has-text-success-70-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-70-invert-l)) !important;
}

.has-background-success-70-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-70-invert-l)) !important;
}

.has-text-success-75 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-75-l)) !important;
}

.has-background-success-75 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-75-l)) !important;
}

.has-text-success-75-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-75-invert-l)) !important;
}

.has-background-success-75-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-75-invert-l)) !important;
}

.has-text-success-80 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-80-l)) !important;
}

.has-background-success-80 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-80-l)) !important;
}

.has-text-success-80-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-80-invert-l)) !important;
}

.has-background-success-80-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-80-invert-l)) !important;
}

.has-text-success-85 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-85-l)) !important;
}

.has-background-success-85 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-85-l)) !important;
}

.has-text-success-85-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-85-invert-l)) !important;
}

.has-background-success-85-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-85-invert-l)) !important;
}

.has-text-success-90 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-90-l)) !important;
}

.has-background-success-90 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-90-l)) !important;
}

.has-text-success-90-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-90-invert-l)) !important;
}

.has-background-success-90-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-90-invert-l)) !important;
}

.has-text-success-95 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-95-l)) !important;
}

.has-background-success-95 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-95-l)) !important;
}

.has-text-success-95-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-95-invert-l)) !important;
}

.has-background-success-95-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-95-invert-l)) !important;
}

.has-text-success-100 {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-100-l)) !important;
}

.has-background-success-100 {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-100-l)) !important;
}

.has-text-success-100-invert {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-100-invert-l)) !important;
}

.has-background-success-100-invert {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), var(--bulma-success-100-invert-l)) !important;
}

a.has-text-success:hover, a.has-text-success:focus-visible,
button.has-text-success:hover,
button.has-text-success:focus-visible,
has-text-success.is-hoverable:hover,
has-text-success.is-hoverable:focus-visible {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), calc(var(--bulma-success-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-success:active,
button.has-text-success:active,
has-text-success.is-hoverable:active {
  color: hsl(var(--bulma-success-h), var(--bulma-success-s), calc(var(--bulma-success-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-success:hover, a.has-background-success:focus-visible,
button.has-background-success:hover,
button.has-background-success:focus-visible,
has-background-success.is-hoverable:hover,
has-background-success.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), calc(var(--bulma-success-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-success:active,
button.has-background-success:active,
has-background-success.is-hoverable:active {
  background-color: hsl(var(--bulma-success-h), var(--bulma-success-s), calc(var(--bulma-success-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-success {
  --h: var(--bulma-success-h);
  --s: var(--bulma-success-s);
  --l: var(--bulma-success-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-success-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-success-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-success-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-success-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-success-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-success-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-success-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-success-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-success-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-success-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-success-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-success-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-success-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-success-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-success-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-success-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-success-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-success-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-success-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-success-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-success-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-warning {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-l)) !important;
}

.has-background-warning {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-l)) !important;
}

.has-text-warning-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-invert-l)) !important;
}

.has-background-warning-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-invert-l)) !important;
}

.has-text-warning-on-scheme {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-on-scheme-l)) !important;
}

.has-background-warning-on-scheme {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-on-scheme-l)) !important;
}

.has-text-warning-light {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-light-l)) !important;
}

.has-background-warning-light {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-light-l)) !important;
}

.has-text-warning-light-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-light-invert-l)) !important;
}

.has-background-warning-light-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-light-invert-l)) !important;
}

.has-text-warning-dark {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-dark-l)) !important;
}

.has-background-warning-dark {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-dark-l)) !important;
}

.has-text-warning-dark-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-dark-invert-l)) !important;
}

.has-background-warning-dark-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-dark-invert-l)) !important;
}

.has-text-warning-soft {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-soft-l)) !important;
}

.has-background-warning-soft {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-soft-l)) !important;
}

.has-text-warning-bold {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-bold-l)) !important;
}

.has-background-warning-bold {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-bold-l)) !important;
}

.has-text-warning-soft-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-warning-soft-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-warning-bold-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-warning-bold-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-warning-00 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-00-l)) !important;
}

.has-background-warning-00 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-00-l)) !important;
}

.has-text-warning-00-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-00-invert-l)) !important;
}

.has-background-warning-00-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-00-invert-l)) !important;
}

.has-text-warning-05 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-05-l)) !important;
}

.has-background-warning-05 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-05-l)) !important;
}

.has-text-warning-05-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-05-invert-l)) !important;
}

.has-background-warning-05-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-05-invert-l)) !important;
}

.has-text-warning-10 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-10-l)) !important;
}

.has-background-warning-10 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-10-l)) !important;
}

.has-text-warning-10-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-10-invert-l)) !important;
}

.has-background-warning-10-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-10-invert-l)) !important;
}

.has-text-warning-15 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-15-l)) !important;
}

.has-background-warning-15 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-15-l)) !important;
}

.has-text-warning-15-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-15-invert-l)) !important;
}

.has-background-warning-15-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-15-invert-l)) !important;
}

.has-text-warning-20 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-20-l)) !important;
}

.has-background-warning-20 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-20-l)) !important;
}

.has-text-warning-20-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-20-invert-l)) !important;
}

.has-background-warning-20-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-20-invert-l)) !important;
}

.has-text-warning-25 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-25-l)) !important;
}

.has-background-warning-25 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-25-l)) !important;
}

.has-text-warning-25-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-25-invert-l)) !important;
}

.has-background-warning-25-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-25-invert-l)) !important;
}

.has-text-warning-30 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-30-l)) !important;
}

.has-background-warning-30 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-30-l)) !important;
}

.has-text-warning-30-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-30-invert-l)) !important;
}

.has-background-warning-30-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-30-invert-l)) !important;
}

.has-text-warning-35 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-35-l)) !important;
}

.has-background-warning-35 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-35-l)) !important;
}

.has-text-warning-35-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-35-invert-l)) !important;
}

.has-background-warning-35-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-35-invert-l)) !important;
}

.has-text-warning-40 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-40-l)) !important;
}

.has-background-warning-40 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-40-l)) !important;
}

.has-text-warning-40-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-40-invert-l)) !important;
}

.has-background-warning-40-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-40-invert-l)) !important;
}

.has-text-warning-45 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-45-l)) !important;
}

.has-background-warning-45 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-45-l)) !important;
}

.has-text-warning-45-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-45-invert-l)) !important;
}

.has-background-warning-45-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-45-invert-l)) !important;
}

.has-text-warning-50 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-50-l)) !important;
}

.has-background-warning-50 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-50-l)) !important;
}

.has-text-warning-50-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-50-invert-l)) !important;
}

.has-background-warning-50-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-50-invert-l)) !important;
}

.has-text-warning-55 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-55-l)) !important;
}

.has-background-warning-55 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-55-l)) !important;
}

.has-text-warning-55-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-55-invert-l)) !important;
}

.has-background-warning-55-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-55-invert-l)) !important;
}

.has-text-warning-60 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-60-l)) !important;
}

.has-background-warning-60 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-60-l)) !important;
}

.has-text-warning-60-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-60-invert-l)) !important;
}

.has-background-warning-60-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-60-invert-l)) !important;
}

.has-text-warning-65 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-65-l)) !important;
}

.has-background-warning-65 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-65-l)) !important;
}

.has-text-warning-65-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-65-invert-l)) !important;
}

.has-background-warning-65-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-65-invert-l)) !important;
}

.has-text-warning-70 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-70-l)) !important;
}

.has-background-warning-70 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-70-l)) !important;
}

.has-text-warning-70-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-70-invert-l)) !important;
}

.has-background-warning-70-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-70-invert-l)) !important;
}

.has-text-warning-75 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-75-l)) !important;
}

.has-background-warning-75 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-75-l)) !important;
}

.has-text-warning-75-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-75-invert-l)) !important;
}

.has-background-warning-75-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-75-invert-l)) !important;
}

.has-text-warning-80 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-80-l)) !important;
}

.has-background-warning-80 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-80-l)) !important;
}

.has-text-warning-80-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-80-invert-l)) !important;
}

.has-background-warning-80-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-80-invert-l)) !important;
}

.has-text-warning-85 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-85-l)) !important;
}

.has-background-warning-85 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-85-l)) !important;
}

.has-text-warning-85-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-85-invert-l)) !important;
}

.has-background-warning-85-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-85-invert-l)) !important;
}

.has-text-warning-90 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-90-l)) !important;
}

.has-background-warning-90 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-90-l)) !important;
}

.has-text-warning-90-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-90-invert-l)) !important;
}

.has-background-warning-90-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-90-invert-l)) !important;
}

.has-text-warning-95 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-95-l)) !important;
}

.has-background-warning-95 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-95-l)) !important;
}

.has-text-warning-95-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-95-invert-l)) !important;
}

.has-background-warning-95-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-95-invert-l)) !important;
}

.has-text-warning-100 {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-100-l)) !important;
}

.has-background-warning-100 {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-100-l)) !important;
}

.has-text-warning-100-invert {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-100-invert-l)) !important;
}

.has-background-warning-100-invert {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), var(--bulma-warning-100-invert-l)) !important;
}

a.has-text-warning:hover, a.has-text-warning:focus-visible,
button.has-text-warning:hover,
button.has-text-warning:focus-visible,
has-text-warning.is-hoverable:hover,
has-text-warning.is-hoverable:focus-visible {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), calc(var(--bulma-warning-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-warning:active,
button.has-text-warning:active,
has-text-warning.is-hoverable:active {
  color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), calc(var(--bulma-warning-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-warning:hover, a.has-background-warning:focus-visible,
button.has-background-warning:hover,
button.has-background-warning:focus-visible,
has-background-warning.is-hoverable:hover,
has-background-warning.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), calc(var(--bulma-warning-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-warning:active,
button.has-background-warning:active,
has-background-warning.is-hoverable:active {
  background-color: hsl(var(--bulma-warning-h), var(--bulma-warning-s), calc(var(--bulma-warning-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-warning {
  --h: var(--bulma-warning-h);
  --s: var(--bulma-warning-s);
  --l: var(--bulma-warning-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-warning-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-warning-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-warning-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-warning-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-warning-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-warning-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-warning-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-warning-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-warning-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-warning-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-warning-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-warning-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-warning-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-warning-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-warning-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-warning-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-warning-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-warning-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-warning-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-warning-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-warning-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-danger {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-l)) !important;
}

.has-background-danger {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-l)) !important;
}

.has-text-danger-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-invert-l)) !important;
}

.has-background-danger-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-invert-l)) !important;
}

.has-text-danger-on-scheme {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-on-scheme-l)) !important;
}

.has-background-danger-on-scheme {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-on-scheme-l)) !important;
}

.has-text-danger-light {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-light-l)) !important;
}

.has-background-danger-light {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-light-l)) !important;
}

.has-text-danger-light-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-light-invert-l)) !important;
}

.has-background-danger-light-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-light-invert-l)) !important;
}

.has-text-danger-dark {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-dark-l)) !important;
}

.has-background-danger-dark {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-dark-l)) !important;
}

.has-text-danger-dark-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-dark-invert-l)) !important;
}

.has-background-danger-dark-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-dark-invert-l)) !important;
}

.has-text-danger-soft {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-soft-l)) !important;
}

.has-background-danger-soft {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-soft-l)) !important;
}

.has-text-danger-bold {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-bold-l)) !important;
}

.has-background-danger-bold {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-bold-l)) !important;
}

.has-text-danger-soft-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-soft-invert-l)) !important;
}

.has-background-danger-soft-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-soft-invert-l)) !important;
}

.has-text-danger-bold-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-bold-invert-l)) !important;
}

.has-background-danger-bold-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-bold-invert-l)) !important;
}

.has-text-danger-00 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-00-l)) !important;
}

.has-background-danger-00 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-00-l)) !important;
}

.has-text-danger-00-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-00-invert-l)) !important;
}

.has-background-danger-00-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-00-invert-l)) !important;
}

.has-text-danger-05 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-05-l)) !important;
}

.has-background-danger-05 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-05-l)) !important;
}

.has-text-danger-05-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-05-invert-l)) !important;
}

.has-background-danger-05-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-05-invert-l)) !important;
}

.has-text-danger-10 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-10-l)) !important;
}

.has-background-danger-10 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-10-l)) !important;
}

.has-text-danger-10-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-10-invert-l)) !important;
}

.has-background-danger-10-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-10-invert-l)) !important;
}

.has-text-danger-15 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-15-l)) !important;
}

.has-background-danger-15 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-15-l)) !important;
}

.has-text-danger-15-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-15-invert-l)) !important;
}

.has-background-danger-15-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-15-invert-l)) !important;
}

.has-text-danger-20 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-20-l)) !important;
}

.has-background-danger-20 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-20-l)) !important;
}

.has-text-danger-20-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-20-invert-l)) !important;
}

.has-background-danger-20-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-20-invert-l)) !important;
}

.has-text-danger-25 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-25-l)) !important;
}

.has-background-danger-25 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-25-l)) !important;
}

.has-text-danger-25-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-25-invert-l)) !important;
}

.has-background-danger-25-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-25-invert-l)) !important;
}

.has-text-danger-30 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-30-l)) !important;
}

.has-background-danger-30 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-30-l)) !important;
}

.has-text-danger-30-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-30-invert-l)) !important;
}

.has-background-danger-30-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-30-invert-l)) !important;
}

.has-text-danger-35 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-35-l)) !important;
}

.has-background-danger-35 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-35-l)) !important;
}

.has-text-danger-35-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-35-invert-l)) !important;
}

.has-background-danger-35-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-35-invert-l)) !important;
}

.has-text-danger-40 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-40-l)) !important;
}

.has-background-danger-40 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-40-l)) !important;
}

.has-text-danger-40-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-40-invert-l)) !important;
}

.has-background-danger-40-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-40-invert-l)) !important;
}

.has-text-danger-45 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-45-l)) !important;
}

.has-background-danger-45 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-45-l)) !important;
}

.has-text-danger-45-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-45-invert-l)) !important;
}

.has-background-danger-45-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-45-invert-l)) !important;
}

.has-text-danger-50 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-50-l)) !important;
}

.has-background-danger-50 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-50-l)) !important;
}

.has-text-danger-50-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-50-invert-l)) !important;
}

.has-background-danger-50-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-50-invert-l)) !important;
}

.has-text-danger-55 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-55-l)) !important;
}

.has-background-danger-55 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-55-l)) !important;
}

.has-text-danger-55-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-55-invert-l)) !important;
}

.has-background-danger-55-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-55-invert-l)) !important;
}

.has-text-danger-60 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-60-l)) !important;
}

.has-background-danger-60 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-60-l)) !important;
}

.has-text-danger-60-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-60-invert-l)) !important;
}

.has-background-danger-60-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-60-invert-l)) !important;
}

.has-text-danger-65 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-65-l)) !important;
}

.has-background-danger-65 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-65-l)) !important;
}

.has-text-danger-65-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-65-invert-l)) !important;
}

.has-background-danger-65-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-65-invert-l)) !important;
}

.has-text-danger-70 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-70-l)) !important;
}

.has-background-danger-70 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-70-l)) !important;
}

.has-text-danger-70-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-70-invert-l)) !important;
}

.has-background-danger-70-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-70-invert-l)) !important;
}

.has-text-danger-75 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-75-l)) !important;
}

.has-background-danger-75 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-75-l)) !important;
}

.has-text-danger-75-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-75-invert-l)) !important;
}

.has-background-danger-75-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-75-invert-l)) !important;
}

.has-text-danger-80 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-80-l)) !important;
}

.has-background-danger-80 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-80-l)) !important;
}

.has-text-danger-80-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-80-invert-l)) !important;
}

.has-background-danger-80-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-80-invert-l)) !important;
}

.has-text-danger-85 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-85-l)) !important;
}

.has-background-danger-85 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-85-l)) !important;
}

.has-text-danger-85-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-85-invert-l)) !important;
}

.has-background-danger-85-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-85-invert-l)) !important;
}

.has-text-danger-90 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-90-l)) !important;
}

.has-background-danger-90 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-90-l)) !important;
}

.has-text-danger-90-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-90-invert-l)) !important;
}

.has-background-danger-90-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-90-invert-l)) !important;
}

.has-text-danger-95 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-95-l)) !important;
}

.has-background-danger-95 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-95-l)) !important;
}

.has-text-danger-95-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-95-invert-l)) !important;
}

.has-background-danger-95-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-95-invert-l)) !important;
}

.has-text-danger-100 {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-100-l)) !important;
}

.has-background-danger-100 {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-100-l)) !important;
}

.has-text-danger-100-invert {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-100-invert-l)) !important;
}

.has-background-danger-100-invert {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), var(--bulma-danger-100-invert-l)) !important;
}

a.has-text-danger:hover, a.has-text-danger:focus-visible,
button.has-text-danger:hover,
button.has-text-danger:focus-visible,
has-text-danger.is-hoverable:hover,
has-text-danger.is-hoverable:focus-visible {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), calc(var(--bulma-danger-l) + var(--bulma-hover-color-l-delta))) !important;
}
a.has-text-danger:active,
button.has-text-danger:active,
has-text-danger.is-hoverable:active {
  color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), calc(var(--bulma-danger-l) + var(--bulma-active-color-l-delta))) !important;
}

a.has-background-danger:hover, a.has-background-danger:focus-visible,
button.has-background-danger:hover,
button.has-background-danger:focus-visible,
has-background-danger.is-hoverable:hover,
has-background-danger.is-hoverable:focus-visible {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), calc(var(--bulma-danger-l) + var(--bulma-hover-background-l-delta))) !important;
}
a.has-background-danger:active,
button.has-background-danger:active,
has-background-danger.is-hoverable:active {
  background-color: hsl(var(--bulma-danger-h), var(--bulma-danger-s), calc(var(--bulma-danger-l) + var(--bulma-active-background-l-delta))) !important;
}

.is-palette-danger {
  --h: var(--bulma-danger-h);
  --s: var(--bulma-danger-s);
  --l: var(--bulma-danger-l);
  --color: hsl(var(--h), var(--s), var(--l));
  --00-l: var(--bulma-danger-00-l);
  --color-00: hsl(var(--h), var(--s), var(--00-l));
  --05-l: var(--bulma-danger-05-l);
  --color-05: hsl(var(--h), var(--s), var(--05-l));
  --10-l: var(--bulma-danger-10-l);
  --color-10: hsl(var(--h), var(--s), var(--10-l));
  --15-l: var(--bulma-danger-15-l);
  --color-15: hsl(var(--h), var(--s), var(--15-l));
  --20-l: var(--bulma-danger-20-l);
  --color-20: hsl(var(--h), var(--s), var(--20-l));
  --25-l: var(--bulma-danger-25-l);
  --color-25: hsl(var(--h), var(--s), var(--25-l));
  --30-l: var(--bulma-danger-30-l);
  --color-30: hsl(var(--h), var(--s), var(--30-l));
  --35-l: var(--bulma-danger-35-l);
  --color-35: hsl(var(--h), var(--s), var(--35-l));
  --40-l: var(--bulma-danger-40-l);
  --color-40: hsl(var(--h), var(--s), var(--40-l));
  --45-l: var(--bulma-danger-45-l);
  --color-45: hsl(var(--h), var(--s), var(--45-l));
  --50-l: var(--bulma-danger-50-l);
  --color-50: hsl(var(--h), var(--s), var(--50-l));
  --55-l: var(--bulma-danger-55-l);
  --color-55: hsl(var(--h), var(--s), var(--55-l));
  --60-l: var(--bulma-danger-60-l);
  --color-60: hsl(var(--h), var(--s), var(--60-l));
  --65-l: var(--bulma-danger-65-l);
  --color-65: hsl(var(--h), var(--s), var(--65-l));
  --70-l: var(--bulma-danger-70-l);
  --color-70: hsl(var(--h), var(--s), var(--70-l));
  --75-l: var(--bulma-danger-75-l);
  --color-75: hsl(var(--h), var(--s), var(--75-l));
  --80-l: var(--bulma-danger-80-l);
  --color-80: hsl(var(--h), var(--s), var(--80-l));
  --85-l: var(--bulma-danger-85-l);
  --color-85: hsl(var(--h), var(--s), var(--85-l));
  --90-l: var(--bulma-danger-90-l);
  --color-90: hsl(var(--h), var(--s), var(--90-l));
  --95-l: var(--bulma-danger-95-l);
  --color-95: hsl(var(--h), var(--s), var(--95-l));
  --100-l: var(--bulma-danger-100-l);
  --color-100: hsl(var(--h), var(--s), var(--100-l));
}

.has-text-black-bis {
  color: hsl(221, 14%, 9%) !important;
}

.has-background-black-bis {
  background-color: hsl(221, 14%, 9%) !important;
}

.has-text-black-ter {
  color: hsl(221, 14%, 14%) !important;
}

.has-background-black-ter {
  background-color: hsl(221, 14%, 14%) !important;
}

.has-text-grey-darker {
  color: hsl(221, 14%, 21%) !important;
}

.has-background-grey-darker {
  background-color: hsl(221, 14%, 21%) !important;
}

.has-text-grey-dark {
  color: hsl(221, 14%, 29%) !important;
}

.has-background-grey-dark {
  background-color: hsl(221, 14%, 29%) !important;
}

.has-text-grey {
  color: hsl(221, 14%, 48%) !important;
}

.has-background-grey {
  background-color: hsl(221, 14%, 48%) !important;
}

.has-text-grey-light {
  color: hsl(221, 14%, 71%) !important;
}

.has-background-grey-light {
  background-color: hsl(221, 14%, 71%) !important;
}

.has-text-grey-lighter {
  color: hsl(221, 14%, 86%) !important;
}

.has-background-grey-lighter {
  background-color: hsl(221, 14%, 86%) !important;
}

.has-text-white-ter {
  color: hsl(221, 14%, 96%) !important;
}

.has-background-white-ter {
  background-color: hsl(221, 14%, 96%) !important;
}

.has-text-white-bis {
  color: hsl(221, 14%, 98%) !important;
}

.has-background-white-bis {
  background-color: hsl(221, 14%, 98%) !important;
}

.has-text-current {
  color: currentColor !important;
}

.has-text-inherit {
  color: inherit !important;
}

.has-background-current {
  background-color: currentColor !important;
}

.has-background-inherit {
  background-color: inherit !important;
}

/*# sourceMappingURL=color.css.map */
